==> speech-analytic-testing_4.2.0_database.tar.gz: database/mssql/procedures/BulkInteractionEvaluationPlan.sql <==
SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO
 CREATE PROCEDURE [dbo].[BulkInteractionEvaluationPlan]
AS
BEGIN
	SET NOCOUNT ON

	-- INSERTAMOS LA DATA DE LA TABLA TEMPORAL
	INSERT INTO [dbo].[InteractionEvaluationPlan] (
			[Instance], [IdEvaluationPlan], [IdAgent],
			[AgentName], [IdCampaign], [IdInteraction], 
			[FormattedEndDate], [InteractionSection], [InteractionPart], 
			[InteractionDateStart], [InteractionDateEnd], [InteractionType], 
			[InteractionMessages], [InteractionDuration], [InteractionOrigin], 
			[ManagementResult], [RelativePath], [FileName],
			[ContactId], [ContactAddress], [ContactName], 
			[InteractionFormat], [NeedI6Update],
			[CreatedByUserId], [CreatedDate], [TimeStamp])
		SELECT IEP.[VCC], IEP.[IdEvaluationPlan], IEP.[IdAgent],
				IEP.[AgentName], IEP.[IdCampaign], IEP.[IdInteraction], 
				IEP.[InteractionFolder], IEP.[InteractionSection], IEP.[InteractionPart], 
				IEP.[InteractionDateStart], IEP.[InteractionDateEnd], IEP.[InteractionType], 
				IEP.[TotalMessages], IEP.[InteractionDuration], IEP.[InteractionOrigin], 
				IEP.[InteractionManagementResult], IEP.[RelativePath], IEP.[FileName],
				IEP.[InteractionContactId], IEP.[InteractionContactAddress], IEP.[InteractionContactName],
				IEP.[InteractionFormat], IEP.[NeedI6Update],
				IEP.[CreatedByUserId], GETUTCDATE(), GETUTCDATE()
			FROM [#InteractionEvaluationPlanTemp] IEP (NOLOCK)
			/*
			LEFT JOIN [dbo].[Agent] A (NOLOCK)
				ON A.[VCC] = IEP.[VCC]
					AND A.[AgentId] = IEP.[IdAgent]
			*/

	-- ELIMINAMOS LA TABLA TEMPORAL 
	DROP TABLE [#InteractionEvaluationPlanTemp]
	
	SET NOCOUNT OFF
END
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO

==> speech-analytic-testing_5.1.0_database.tar.gz: database/mssql/procedures/BulkInteractionEvaluationPlan.sql <==
SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO
CREATE PROCEDURE [dbo].[BulkInteractionEvaluationPlan]
AS
BEGIN
	SET NOCOUNT ON

	-- DECLARAMOS UNA VARIABLE PARA DEFINIR EL VCC
	DECLARE @VCC VARCHAR(50) = NULL
	DECLARE @VCC_TYPE VARCHAR(50) = NULL
	DECLARE @NEED_I6_UPDATE BIT = 0 

	-- ASIGNAMOS A LA VARIABLE EL NOMBRE DEL VCC
	SELECT TOP 1 @VCC = [VCC] FROM [#InteractionEvaluationPlanTemp] (NOLOCK)

	-- BUSCAMOS EL TIPO DE VCC
	SELECT @VCC_TYPE = V.[Type] FROM [dbo].[VCC] V (NOLOCK) WHERE V.[VCC] = @VCC

	-- CAMBIAMOS EL VALOR DEL FLAG
	IF @VCC_TYPE = 'I6' SET @NEED_I6_UPDATE = 1

	-- INSERTAMOS LA DATA DE LA TABLA TEMPORAL
	INSERT INTO [dbo].[InteractionEvaluationPlan] (
			[Instance], [IdEvaluationPlan], [IdAgent],
			[AgentName], [IdCampaign], [IdInteraction], 
			[FormattedEndDate], [InteractionSection], [InteractionPart], 
			[InteractionDateStart], [InteractionDateEnd], [InteractionType], 
			[InteractionMessages], [InteractionDuration], [InteractionOrigin], 
			[ManagementResult], [RelativePath], [FileName],
			[ContactId], [ContactAddress], [ContactName], 
			[InteractionFormat], 
			[NeedI6Update],
			[CreatedByUserId], [CreatedDate], [TimeStamp])
		SELECT IEP.[VCC], IEP.[IdEvaluationPlan], IEP.[IdAgent],
				IEP.[AgentName], IEP.[IdCampaign], IEP.[IdInteraction], 
				IEP.[InteractionFolder], IEP.[InteractionSection], IEP.[InteractionPart], 
				IEP.[InteractionDateStart], IEP.[InteractionDateEnd], IEP.[InteractionType], 
				IEP.[TotalMessages], IEP.[InteractionDuration], IEP.[InteractionOrigin], 
				IEP.[InteractionManagementResult], IEP.[RelativePath], IEP.[FileName],
				IEP.[InteractionContactId], IEP.[InteractionContactAddress], IEP.[InteractionContactName],
				IEP.[InteractionFormat], 
				CASE WHEN @VCC_TYPE = 'OCC'
					THEN IIF(IEP.[InteractionType] = 'CALL', 0 , 1) 
					ELSE @NEED_I6_UPDATE
					END,
				IEP.[CreatedByUserId], GETUTCDATE(), GETUTCDATE()
			FROM [#InteractionEvaluationPlanTemp] IEP (NOLOCK)
			/*
			LEFT JOIN [dbo].[Agent] A (NOLOCK)
				ON A.[VCC] = IEP.[VCC]
					AND A.[AgentId] = IEP.[IdAgent]
			*/

	-- ELIMINAMOS LA TABLA TEMPORAL 
	DROP TABLE [#InteractionEvaluationPlanTemp]
	
	SET NOCOUNT OFF
END
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO
